@@ -24,7 +24,7 @@
 #include <glib-object.h>
 
 #include "s-common-address.h"
-#include "s-common.h"
+#include "s-common-utils.h"
 
 static gboolean no_fork = FALSE;
 static gboolean verbose = FALSE;
@@ -45,6 +45,8 @@ main (int argc, char **argv)
 
         failed = 0;
 
+        g_type_init ();
+
         context = g_option_context_new ("");
         g_option_context_add_main_entries (context, entries, NULL);
         error = NULL;
@@ -54,10 +56,11 @@ main (int argc, char **argv)
         if (error != NULL) {
                 g_warning ("%s", error->message);
                 g_error_free (error);
-                exit (EXIT_FAILURE);
+                exit (1);
         }
 
-        r = srunner_create (suite_common_address ());
+        r = srunner_create (suite_common_utils ());
+        srunner_add_suite (r, suite_common_address ());
 
         if (no_fork) {
                 srunner_set_fork_status (r, CK_NOFORK);
@@ -67,15 +70,5 @@ main (int argc, char **argv)
         failed = srunner_ntests_failed (r);
         srunner_free (r);
 
-        r = srunner_create (suite_common ());
-
-        if (no_fork) {
-                srunner_set_fork_status (r, CK_NOFORK);
-        }
-
-        srunner_run_all (r, verbose ? CK_VERBOSE : CK_NORMAL);
-        failed |= srunner_ntests_failed (r);
-        srunner_free (r);
-
         return failed != 0;
 }
